@@ -12,17 +12,25 @@ m <- dbDriver("SQLite")
 con <- dbConnect(m, dbname="test") # no user/passwd/host
 
 dbListTables(con) 
-source(system.file("TSsql/CreateTables.TSsql", package = "TSdbi"))
+
+#source(system.file("TSsql/CreateTables.TSsql", package = "TSsql"))
+require("TSsql")
+removeTSdbTables(con, yesIknowWhatIamDoing=TRUE)
+createTSdbTables(con, index=FALSE)
+
 dbListTables(con) 
 dbDisconnect(con)
 
 con <- try(TSconnect(m, dbname="test") )
 if(inherits(con, "try-error")) stop("CreateTables did not work.")
 
-source(system.file("TSsql/Populate.TSsql", package = "TSdbi"))
-source(system.file("TSsql/TSdbi.TSsql", package = "TSdbi"))
-source(system.file("TSsql/dbGetQuery.TSsql", package = "TSdbi"))
-source(system.file("TSsql/HistQuote.TSsql", package = "TSdbi"))
+source(system.file("TSsql/Populate.TSsql", package = "TSsql"))
+source(system.file("TSsql/TSdbi.TSsql", package = "TSsql"))
+source(system.file("TSsql/dbGetQuery.TSsql", package = "TSsql"))
+source(system.file("TSsql/HistQuote.TSsql", package = "TSsql"))
+
+cat("**************        remove test tables\n")
+removeTSdbTables(con, yesIknowWhatIamDoing=TRUE)
 
 cat("**************        disconnecting test\n")
 dbDisconnect(con)
